@@ -22,6 +22,7 @@
 #include <QCommandLineParser>
 
 #include <KAboutData>
+#include <KCrash>
 #include <KLocalizedString>
 
 
@@ -44,6 +45,8 @@ int main (int argc, char *argv[])
                                )
                         );
 
+    KCrash::initialize();
+
     aboutData.addAuthor(i18n("Stefan Böhmann"), i18n("Current maintainer"), QStringLiteral("kde@hilefoks.org"), QStringLiteral("http://www.hilefoks.org"), QStringLiteral("hilefoks"));
     aboutData.addAuthor(i18n("Matthias Hoelzer-Kluepfel"), QString(), QStringLiteral("hoelzer@kde.org"));
     aboutData.addAuthor(i18n("Martin Willers"), QString(), QStringLiteral("willers@xm-arts.de"));
@@ -77,8 +80,6 @@ int main (int argc, char *argv[])
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     parser.setApplicationDescription(aboutData.shortDescription());
-    parser.addHelpOption();
-    parser.addVersionOption();
 
     QCommandLineOption timeOption(QStringList() << QStringLiteral("t") << QStringLiteral("time"), i18n("Start a new tea with this time."), i18n("seconds"));
     parser.addOption(timeOption);
@@ -93,7 +94,7 @@ int main (int argc, char *argv[])
     const int time=parser.value(timeOption).toInt();
     if( time > 0 ) {
         const QString name = parser.value(nameOption);
-        const Tea tea( name == QString() ? i18n( "Anonymous Tea" ) : name, time );
+        const Tea tea( name.isEmpty() ? i18n( "Anonymous Tea" ) : name, time );
         toplevel->runTea( tea );
     }
 
